@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;    #inherits
 use Lemonldap::NG::Common::Conf::SAML::Metadata;
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.5';
 our @ISA     = qw(Lemonldap::NG::Portal::_SAML);
 
 ## @apmethod int authInit()
@@ -906,7 +906,7 @@ sub extractFormInfo {
     my $method =
       $self->{samlIDPMetaDataOptions}->{$idpConfKey}
       ->{samlIDPMetaDataOptionsSSOBinding};
-    $method = $self->getHttpMethod($method) if $method;
+    $method = $self->getHttpMethod($method);
 
     # If no method defined, get first HTTP method
     unless ( defined $method ) {
@@ -1277,7 +1277,7 @@ sub authLogout {
     $method =
       $self->{samlIDPMetaDataOptions}->{$idpConfKey}
       ->{samlIDPMetaDataOptionsSLOBinding};
-    $method = $self->getHttpMethod($method) if $method;
+    $method = $self->getHttpMethod($method);
 
     # If no method defined, get first HTTP method
     unless ( defined $method ) {
@@ -1435,9 +1435,16 @@ sub authForce {
 }
 
 ## @apmethod boolean authFinish()
-# Associate NameID and SessionIndex to a local session
+# Do nothing
 # @return Lemonldap::NG::Portal error code
 sub authFinish {
+    PE_OK;
+}
+
+## @apmethod boolean authPostStore()
+# Associate NameID and SessionIndex to a local session
+# @return Lemonldap::NG::Portal error code
+sub authPostStore {
     my $self = shift;
     my %h;
 
