@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;
 our @ISA = qw(Lemonldap::NG::Portal::_SAML);
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.5';
 
 ## @method void issuerDBInit()
 # Load and check SAML configuration
@@ -75,13 +75,10 @@ sub issuerForUnAuthUser {
         2 );
     my $saml_ars_url = $self->getMetaDataURL(
         "samlIDPSSODescriptorArtifactResolutionServiceArtifact");
-    my $saml_slo_url_relay_soap =
-      $self->{portal} . '/saml/relaySingleLogoutSOAP';
-    my $saml_slo_url_relay_post =
-      $self->{portal} . '/saml/relaySingleLogoutPOST';
-    my $saml_slo_url_relay_term =
-      $self->{portal} . '/saml/relaySingleLogoutTermination';
-    my $saml_att_soap_url = $self->getMetaDataURL(
+    my $saml_slo_url_relay_soap = '/saml/relaySingleLogoutSOAP';
+    my $saml_slo_url_relay_post = '/saml/relaySingleLogoutPOST';
+    my $saml_slo_url_relay_term = '/saml/relaySingleLogoutTermination';
+    my $saml_att_soap_url       = $self->getMetaDataURL(
         "samlAttributeAuthorityDescriptorAttributeServiceSOAP", 1 );
 
     # Get HTTP request informations to know
@@ -1008,8 +1005,11 @@ sub issuerForUnAuthUser {
                         }
 
                         # SAML2 attribute value
-                        my $saml2value =
-                          $self->createAttributeValue($local_value);
+                        my $saml2value = $self->createAttributeValue(
+                            $local_value,
+                            $self->{samlSPMetaDataOptions}->{$spConfKey}
+                              ->{samlSPMetaDataOptionsForceUTF8}
+                        );
 
                         unless ($saml2value) {
                             $self->lmLog(
@@ -1627,7 +1627,9 @@ sub issuerForAuthUser {
                 foreach (@values) {
 
                     # SAML2 attribute value
-                    my $saml2value = $self->createAttributeValue($_);
+                    my $saml2value = $self->createAttributeValue( $_,
+                        $self->{samlSPMetaDataOptions}->{$spConfKey}
+                          ->{samlSPMetaDataOptionsForceUTF8} );
 
                     unless ($saml2value) {
                         $self->lmLog(
