@@ -16,7 +16,7 @@ use Crypt::OpenSSL::Bignum;
 use utf8;
 use base qw(Lemonldap::NG::Portal::_Browser);
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.3';
 our $oidcCache;
 
 BEGIN {
@@ -1149,7 +1149,7 @@ sub getAttributesListFromClaim {
 
     # Additional claims
     my $extraClaims =
-      $self->{oidcRPMetaDataOptions}->{$rp}->{oidcRPMetaDataOptionsExtraClaims};
+      $self->{oidcRPMetaDataOptionsExtraClaims}->{$rp};
 
     if ($extraClaims) {
         foreach my $claim ( keys %$extraClaims ) {
